==> trend_etl-1.0.1.tar.gz: trend_etl-1.0.1/trend_etl/tasks/load_posts.py <==
import argparse
from typing import cast

from delta.tables import DeltaTable
from pyspark.sql import SparkSession

from trend_etl.functions.index import (
    full_table_name,
    facebook_posts_upsert_to_delta,
    get_silver_table,
)
from trend_etl.transform.posts import from_bronze_get_posts_df
import trend_etl.schema.args as arguments
from trend_etl.schema.types import Merge_Strategy

program = "load_posts"


def main() -> None:
    parser = argparse.ArgumentParser(description=f"Arguments for Trend ETL/{program}.")

    parser.add_argument(
        "--bronze-catalog",
        dest="bronze_catalog",
        required=True,
        choices=arguments.catalogs,
        help="The unit catalog to use",
    )

    parser.add_argument(
        "--target-catalog",
        dest="target_catalog",
        required=True,
        choices=arguments.catalogs,
        help="The unit catalog to use",
    )

    parser.add_argument(
        "--checkpoints-path-prefix",
        dest="checkpoints_path_prefix",
        required=True,
        help="The path to the folder (in S3) to store the checkpoints for this table",
    )

    parser.add_argument(
        "--keep-oldest",
        dest="keep_oldest",
        required=True,
        choices=arguments.yesno,
        help="Keep newest or oldest when using the merge to drop duplicates",
    )

    args = parser.parse_args()

    spark = cast(SparkSession, SparkSession.builder.appName(program).getOrCreate())

    kafka_posts_table = full_table_name(
        args.bronze_catalog,
        arguments.schemas[arguments.schemas_bronze],
        arguments.tables[arguments.tables_posts],
    )
    streaming_kafka_posts = spark.readStream.format("delta").table(kafka_posts_table)

    group_idents_table = full_table_name(
        args.target_catalog,
        arguments.schemas[arguments.schemas_silver],
        arguments.tables[arguments.tables_group_idents],
    )
    group_idents = spark.read.format("delta").table(group_idents_table)

    post_idents_table = full_table_name(
        args.target_catalog,
        arguments.schemas[arguments.schemas_silver],
        arguments.tables[arguments.tables_post_idents],
    )
    post_idents = spark.read.format("delta").table(post_idents_table)

    facebook_posts_table = full_table_name(
        args.target_catalog,
        arguments.schemas[arguments.schemas_silver],
        get_silver_table(args.target_catalog, arguments.tables_facebook_posts),
    )
    checkpoint_loc = f"{args.checkpoints_path_prefix}/{arguments.tables[arguments.tables_facebook_posts]}"
    delta_table = DeltaTable.forName(spark, facebook_posts_table)
    strategy: Merge_Strategy = (
        "keep-oldest" if args.keep_oldest == "yes" else "keep-newest"
    )

    (
        from_bronze_get_posts_df(streaming_kafka_posts, group_idents, post_idents)
        .writeStream.format("delta")
        .foreachBatch(
            lambda batch_df, batch_id: facebook_posts_upsert_to_delta(
                delta_table, strategy, batch_df
            )
        )
        .option("checkpointLocation", checkpoint_loc)
        .outputMode("append")
        .trigger(availableNow=True)
        .start()
    )


if __name__ == "__main__":
    main()

==> trend_etl-1.4.7.tar.gz: trend_etl-1.4.7/trend_etl/tasks/load_posts.py <==
import argparse
from typing import cast

from delta.tables import DeltaTable
from pyspark.sql import SparkSession

from trend_etl.functions.index import (
    full_table_name,
    facebook_posts_upsert_to_delta,
    get_silver_table,
)
from trend_etl.transform.posts import from_bronze_get_posts_df
import trend_etl.schema.args as arguments
from trend_etl.schema.types import Merge_Strategy

program = "load_posts"


def main() -> None:
    parser = argparse.ArgumentParser(description=f"Arguments for Trend ETL/{program}.")

    parser.add_argument(
        "--bronze-catalog",
        dest="bronze_catalog",
        required=True,
        choices=arguments.catalogs,
        help="The unit catalog to use",
    )

    parser.add_argument(
        "--target-catalog",
        dest="target_catalog",
        required=True,
        choices=arguments.catalogs,
        help="The unit catalog to use",
    )

    parser.add_argument(
        "--checkpoints-path-prefix",
        dest="checkpoints_path_prefix",
        required=True,
        help="The path to the folder (in S3) to store the checkpoints for this table",
    )

    parser.add_argument(
        "--keep-oldest",
        dest="keep_oldest",
        required=True,
        choices=arguments.yesno,
        help="Keep newest or oldest when using the merge to drop duplicates",
    )

    args = parser.parse_args()

    spark = cast(SparkSession, SparkSession.builder.appName(program).getOrCreate())

    kafka_posts_table = full_table_name(
        args.bronze_catalog,
        arguments.schemas[arguments.schemas_bronze],
        arguments.tables[arguments.tables_posts],
    )
    streaming_kafka_posts = spark.readStream.format("delta").table(kafka_posts_table)

    group_idents_table = full_table_name(
        args.target_catalog,
        arguments.schemas[arguments.schemas_silver],
        arguments.tables[arguments.tables_group_idents],
    )
    group_idents = spark.read.format("delta").table(group_idents_table)

    post_idents_table = full_table_name(
        args.target_catalog,
        arguments.schemas[arguments.schemas_silver],
        arguments.tables[arguments.tables_post_idents],
    )
    post_idents = spark.read.format("delta").table(post_idents_table)

    facebook_posts_table = full_table_name(
        args.target_catalog,
        arguments.schemas[arguments.schemas_silver],
        get_silver_table(args.target_catalog, arguments.tables_facebook_posts),
    )
    checkpoint_loc = f"{args.checkpoints_path_prefix}/facebook_posts_noparts"
    delta_table = DeltaTable.forName(spark, facebook_posts_table)
    strategy: Merge_Strategy = (
        "keep-oldest" if args.keep_oldest == "yes" else "keep-newest"
    )

    (
        from_bronze_get_posts_df(streaming_kafka_posts, group_idents, post_idents)
        .writeStream.format("delta")
        .foreachBatch(
            lambda batch_df, batch_id: facebook_posts_upsert_to_delta(
                delta_table, strategy, batch_df
            )
        )
        .option("checkpointLocation", checkpoint_loc)
        .outputMode("append")
        .trigger(availableNow=True)
        .start()
    )


if __name__ == "__main__":
    main()
